summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepasswordedaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepasswordedaccount.h')
-rw-r--r--kopete/libkopete/kopetepasswordedaccount.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopetepasswordedaccount.h b/kopete/libkopete/kopetepasswordedaccount.h
index a9fa2f54..4be22016 100644
--- a/kopete/libkopete/kopetepasswordedaccount.h
+++ b/kopete/libkopete/kopetepasswordedaccount.h
@@ -41,25 +41,25 @@ public:
/**
* KopetePasswordedAccount constructor
* @param tqparent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
* @param name The name for this TQObject
*
* @deprecated Use the constructor that specifies if a blank password is allowed
*/
- PasswordedAccount( Protocol *tqparent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
+ PasswordedAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
/**
* KopetePasswordedAccount constructor
* @param tqparent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
* @param allowBlankPassword If this protocol allows blank passwords. Note that this will mean that
*
* @param name The name for this TQObject
*/
- PasswordedAccount( Protocol *tqparent, const TQString &acctId, uint maxPasswordLength = 0,
+ PasswordedAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0,
bool allowBlankPassword = false, const char *name = 0 );
virtual ~PasswordedAccount();
@@ -41,25 +41,25 @@ public:
/**
* KopetePasswordedAccount constructor
- * @param tqparent The protocol this account connects via
+ * @param parent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
@@ -41,25 +41,25 @@ public:
/**
* KopetePasswordedAccount constructor
- * @param tqparent The protocol this account connects via
+ * @param parent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit